analphipy.PhiAnalytic
=====================

.. currentmodule:: analphipy

.. autoclass:: PhiAnalytic

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~PhiAnalytic.__init__
      ~PhiAnalytic.asdict
      ~PhiAnalytic.assign
      ~PhiAnalytic.assign_min_numeric
      ~PhiAnalytic.cut
      ~PhiAnalytic.dphidr
      ~PhiAnalytic.lfs
      ~PhiAnalytic.minimize
      ~PhiAnalytic.new_like
      ~PhiAnalytic.phi
      ~PhiAnalytic.to_measures
      ~PhiAnalytic.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~PhiAnalytic.phi_min
      ~PhiAnalytic.r_min
      ~PhiAnalytic.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~PhiAnalytic.__repr__
   
   